@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: framework/NLS/NLS.php,v 1.82.4.23 2009/04/04 12:30:50 jan Exp $
+ * $Horde: framework/NLS/NLS.php,v 1.82.4.26 2009-08-28 09:01:53 jan Exp $
  *
  * @package Horde_NLS
  */
@@ -133,6 +133,7 @@ class NLS {
             }
         }
 
+        @putenv('LC_ALL=' . $lang_charset);
         @putenv('LANG=' . $lang_charset);
         @putenv('LANGUAGE=' . $lang_charset);
     }
@@ -504,8 +505,14 @@ class NLS {
                 $resolver = new Net_DNS_Resolver();
                 $resolver->retry = isset($GLOBALS['conf']['dns']['retry']) ? $GLOBALS['conf']['dns']['retry'] : 1;
                 $resolver->retrans = isset($GLOBALS['conf']['dns']['retrans']) ? $GLOBALS['conf']['dns']['retrans'] : 1;
-                $response = $resolver->query($host, 'PTR');
-                $checkHost = $response ? $response->answer[0]->ptrdname : $host;
+                if ($response = $resolver->query($host, 'PTR')) {
+                    foreach ($response->answer as $val) {
+                        if (isset($val->ptrdname)) {
+                            $checkHost = $val->ptrdname;
+                            break;
+                        }
+                    }
+                }
             } else {
                 $checkHost = @gethostbyaddr($host);
             }
