@@ -12,7 +12,7 @@ include_once 'Horde/NLS.php';
 /**
  * Class representing iCalendar files.
  *
- * $Horde: framework/iCalendar/iCalendar.php,v 1.57.4.75 2009/04/05 21:37:35 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar.php,v 1.57.4.78 2009-10-01 10:34:06 jan Exp $
  *
  * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
@@ -592,7 +592,11 @@ class Horde_iCalendar {
         }
 
         // Unfold any folded lines.
-        $vCal = preg_replace('/[\r\n]+[ \t]/', '', $vCal);
+        if ($this->isOldFormat()) {
+            $vCal = preg_replace('/[\r\n]+([ \t])/', '$1', $vCal);
+        } else {
+            $vCal = preg_replace('/[\r\n]+[ \t]/', '', $vCal);
+        }
 
         // Parse the remaining attributes.
         if (preg_match_all('/^((?:[^":]+|(?:"[^"]*")+)*):([^\r\n]*)\r?$/m', $vCal, $matches)) {
@@ -655,6 +659,7 @@ class Horde_iCalendar {
 
                 case 'BDAY':
                 case 'X-SYNCJE-ANNIVERSARY':
+                case 'X-ANNIVERSARY':
                     $this->setAttribute($tag, $this->_parseDate($value), $params);
                     break;
 
@@ -1233,16 +1238,11 @@ class Horde_iCalendar {
         $temp = array();
         if (!is_object($value) && !is_array($value)) {
             $tz = date('O', $value);
-            $TZOffset = (3600 * substr($tz, 0, 3)) + (60 * substr(date('O', $value), 3, 2));
+            $TZOffset = (3600 * substr($tz, 0, 3)) + (60 * substr($tz, 3, 2));
             $value -= $TZOffset;
 
             $temp['zone']   = 'UTC';
-            $temp['year']   = date('Y', $value);
-            $temp['month']  = date('n', $value);
-            $temp['mday']   = date('j', $value);
-            $temp['hour']   = date('G', $value);
-            $temp['minute'] = date('i', $value);
-            $temp['second'] = date('s', $value);
+            list($temp['year'], $temp['month'], $temp['mday'], $temp['hour'], $temp['minute'], $temp['second']) = explode('-', date('Y-n-j-G-i-s', $value));
         } else {
             $dateOb = new Horde_Date($value);
             return Horde_iCalendar::_exportDateTime($dateOb->timestamp());
