@@ -2,7 +2,7 @@
 /**
  * @package SyncML
  *
- * $Horde: framework/SyncML/SyncML/Device/Sync4j.php,v 1.8.2.25 2009/04/05 21:38:49 jan Exp $
+ * $Horde: framework/SyncML/SyncML/Device/Sync4j.php,v 1.8.2.34 2009-10-26 18:06:48 jan Exp $
  */
 
 /** Horde_Date */
@@ -253,8 +253,8 @@ class SyncML_Device_sync4j extends SyncML_Device {
             'OtherTelephoneNumber' => array('TEL'),
             'OtherFaxNumber' => array('TEL'),
             'Email1Address' => array('EMAIL'),
-            'Email2Address' => array('EMAIL'),
-            'Email3Address' => array('EMAIL'),
+            'Email2Address' => array('EMAIL', array('TYPE' => 'HOME')),
+            'Email3Address' => array('EMAIL', array('TYPE' => 'WORK')),
             'HomeLabel' => array('LABEL', array('TYPE' => 'HOME')),
             'BusinessLabel' => array('LABEL', array('TYPE' => 'WORK')),
             'OtherLabel' => array('LABEL'),
@@ -425,10 +425,12 @@ class SyncML_Device_sync4j extends SyncML_Device {
             case 5:
                 /* olYearly */
                 $freq = 'YEARLY';
+                $interval = ';INTERVAL=' . $a['Interval'];
                 break;
             case 6:
                 /* olYearNth */
                 $freq = 'YEARLY';
+                $interval = ';INTERVAL=' . $a['Interval'];
                 break;
             }
             $rrule = 'FREQ=' . $freq;
@@ -698,7 +700,13 @@ class SyncML_Device_sync4j extends SyncML_Device {
 
             case 'TEL':
                 if (isset($item['params']['FAX'])) {
-                    $hash['BusinessFaxNumber'] = $item['value'];
+                    if (isset($item['params']['WORK'])) {
+                        $hash['BusinessFaxNumber'] = $item['value'];
+                    } elseif (isset($item['params']['HOME'])) {
+                        $hash['HomeFaxNumber'] = $item['value'];
+                    } else {
+                        $hash['OtherFaxNumber'] = $item['value'];
+                    }
                 } elseif (isset($item['params']['TYPE'])) {
                     if (!is_array($item['params']['TYPE'])) {
                         $item['params']['TYPE'] = array($item['params']['TYPE']);
@@ -729,9 +737,31 @@ class SyncML_Device_sync4j extends SyncML_Device {
                 break;
 
             case 'EMAIL':
-                if (isset($item['params']['PREF']) || !isset($hash['email'])) {
-                    $hash['Email1Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
-                    $hash['Email1AddressType'] = 'SMTP';
+                $email_set = false;
+                if (isset($item['params']['HOME']) && (!isset($hash['Email2Address']) ||
+                    isset($item['params']['PREF']))) {
+                   $hash['Email2Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
+                   $email_set = true;
+                } elseif (isset($item['params']['WORK']) && (!isset($hash['Email3Address']) || 
+                          isset($item['params']['PREF']))) {
+                   $hash['Email3Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
+                   $email_set = true;
+                } elseif (isset($item['params']['TYPE'])) {
+                   if (!is_array($item['params']['TYPE'])) {
+                      $item['params']['TYPE'] = array($item['params']['TYPE']);
+                   }
+                   if (in_array('HOME', $item['params']['TYPE']) && 
+                       (!isset($hash['Email2Address']) || in_array('PREF', $item['params']['TYPE']))) {
+                      $hash['Email2Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
+                      $email_set = true;
+                   } elseif (in_array('WORK', $item['params']['TYPE']) &&
+                             (!isset($hash['Email3Address']) || in_array('PREF', $item['params']['TYPE']))) {
+                      $hash['Email3Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
+                      $email_set = true;
+                   }
+                }
+                if (!$email_set && (!isset($hash['Email1Address']) || isset($item['params']['PREF']))) {
+                   $hash['Email1Address'] = Horde_iCalendar_vcard::getBareEmail($item['value']);
                 }
                 break;
 
@@ -829,7 +859,26 @@ class SyncML_Device_sync4j extends SyncML_Device {
         $hash = array('ReminderSet' => 0,
                       'IsRecurring' => 0,
                       'BusyStatus' => 2);
-        $alarm = null;
+        $alarm = $end = null;
+        $start = $content->getAttribute('DTSTART');
+        if ($start) {
+            if (!empty($start['params']['VALUE']) &&
+                $start['params']['VALUE'] == 'DATE') {
+                $hash['AllDayEvent'] = 1;
+                $hash['Start'] = sprintf('%04d-%02d-%02d',
+                                         $start['value']['year'],
+                                         $start['value']['month'],
+                                         $start['value']['mday']);
+                $start = mktime(0, 0, 0,
+                                $start['value']['month'],
+                                $start['value']['mday'],
+                                $start['value']['year']);
+            } else {
+                $hash['AllDayEvent'] = 0;
+                $hash['Start'] = Horde_iCalendar::_exportDateTime($start);
+            }
+        }
+
         foreach ($content->getAllAttributes() as $item) {
             $GLOBALS['backend']->logMessage(
                 sprintf('Sync4j for name %s, value %s',
@@ -840,37 +889,19 @@ class SyncML_Device_sync4j extends SyncML_Device {
 
             switch (String::upper($item['name'])) {
             case 'DTSTART':
-                if (!empty($item['params']['VALUE']) &&
-                    $item['params']['VALUE'] == 'DATE') {
-                    $hash['AllDayEvent'] = 1;
-                    $hash['Start'] = sprintf('%04d-%02d-%02dT00:00:00Z',
-                                             $item['value']['year'],
-                                             $item['value']['month'],
-                                             $item['value']['mday']);
-                    $start = mktime(0, 0, 0,
-                                    $item['value']['month'],
-                                    $item['value']['mday'],
-                                    $item['value']['year']);
-                } else {
-                    $hash['AllDayEvent'] = 0;
-                    $hash['Start'] = Horde_iCalendar::_exportDateTime
-                        ($item['value']);
-                    $start = $item['value'];
-                }
                 break;
 
             case 'DTEND':
                 if (!empty($item['params']['VALUE']) &&
                     $item['params']['VALUE'] == 'DATE') {
                     $hash['AllDayEvent'] = 1;
-                    $hash['End'] = sprintf('%04d-%02d-%02dT00:00:00Z',
-                                           $item['value']['year'],
-                                           $item['value']['month'],
-                                           $item['value']['mday']);
-                    $end = mktime(0, 0, 0,
-                                  $item['value']['month'],
-                                  $item['value']['mday'],
-                                  $item['value']['year']);
+                    $date = new Horde_Date(array('year' => $item['value']['year'],
+                                                 'month' => $item['value']['month'],
+                                                 'mday' => $item['value']['mday']));
+                    $date->mday--;
+                    $date->correct();
+                    $hash['End'] = $date->format('Y-m-d');
+                    $end = $date->datestamp();
                 } else {
                     $hash['AllDayEvent'] = 0;
                     $hash['End'] = Horde_iCalendar::_exportDateTime(
@@ -983,18 +1014,20 @@ class SyncML_Device_sync4j extends SyncML_Device {
                         $hash['DayOfWeekMask'] = $mask;
                     } else {
                         $hash['RecurrenceType'] = 2;
-                        $start = $content->getAttribute('DTSTART');
-                        if (!empty($start['params']['VALUE']) &&
-                            $start['params']['VALUE'] == 'DATE') {
-                            $hash['DayOfMonth'] = $start['value']['mday'];
-                        } else {
-                            $hash['DayOfMonth'] = date('j', $start);
-                        }
+                        $hash['DayOfMonth'] = date('j', $start);
                     }
                     break;
 
                 case 'YEARLY':
-                    $hash['RecurrenceType'] = 6;
+                    if (isset($rdata['BYDAY'])) {
+                        $hash['RecurrenceType'] = 6;
+                        $hash['Instance'] = $instance;
+                        $hash['DayOfWeekMask'] = $mask;
+                    } else {
+                        $hash['RecurrenceType'] = 5;
+                        $hash['DayOfMonth'] = date('j', $start);
+                    }
+                    $hash['MonthOfYear'] = date('n', $start);
                     break;
                 }
 
@@ -1070,6 +1103,7 @@ class SyncML_Device_sync4j extends SyncML_Device {
         }
 
         $hash['Complete'] = 0;
+        $due = false;
 
         $attr = $content->getAllAttributes();
         foreach ($attr as $item) {
@@ -1098,6 +1132,7 @@ class SyncML_Device_sync4j extends SyncML_Device {
 
             case 'DUE':
                 $hash['DueDate'] = Horde_iCalendar::_exportDateTime($item['value']);
+                $due = $item['value'];
                 break;
 
             case 'AALARM':
@@ -1131,6 +1166,20 @@ class SyncML_Device_sync4j extends SyncML_Device {
             }
         }
 
+        if ($due && !isset($hash['ReminderSet'])) {
+            // Parse VALARM components.
+            foreach ($content->getComponents() as $component) {
+                if (!is_a($component, 'Horde_iCalendar_valarm') ||
+                    is_a($trigger = $component->getAttribute('TRIGGER'), 'PEAR_Error') ||
+                    is_array($trigger) ||
+                    empty($trigger)) {
+                    continue;
+                }
+                $hash['ReminderSet'] = 1;
+                $hash['ReminderTime'] = Horde_iCalendar::_exportDateTime($due - $trigger);
+            }
+        }
+
         return SyncML_Device_sync4j::array2sif(
             $hash,
             '<?xml version="1.0"?><task>',
